@@ -2,8 +2,8 @@
 #
 # read.cross.csv.R
 #
-# copyright (c) 2000-4, Karl W Broman, Johns Hopkins University
-# last modified Apr, 2004
+# copyright (c) 2000-5, Karl W Broman, Johns Hopkins University
+# last modified Sep, 2005
 # first written Aug, 2000
 # Licensed under the GNU General Public License version 2 (June, 1991)
 #
@@ -169,11 +169,11 @@ function(dir, file, na.strings=c("-","NA"),
   n.ind1 <- nrow(pheno)
   n.ind2 <- sapply(geno,function(a) nrow(a$data))
   if(any(n.ind1 != n.ind2)) {
-    print(c(n.ind1,n.ind2))
+    cat(n.ind1,n.ind2,"\n")
     stop("Number of individuals in genotypes and phenotypes do not match.");
   }
   if(any(n.mar1 != n.mar2)) {
-    print(c(n.mar,n.mar2))
+    cat(n.mar1,n.mar2,"\n")
     stop("Numbers of markers in genotypes and marker names files do not match.");
   }
 
